@@ -1,16 +1,15 @@
 
 /*
  *  agUtils.c
- *  $Id: agUtils.c,v 4.19 2008/01/23 00:36:00 bkorb Exp $
+ *  $Id: agUtils.c,v 4.21 2009/01/01 16:51:41 bkorb Exp $
  *
- *  Time-stamp:        "2007-11-12 20:43:32 bkorb"
- *  Last Committed:    $Date: 2008/01/23 00:36:00 $
+ *  Time-stamp:        "2008-07-26 10:00:15 bkorb"
+ *  Last Committed:    $Date: 2009/01/01 16:51:41 $
  *
  *  This is the main routine for autogen.
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
- *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -368,6 +367,21 @@ skipScheme( tCC* pzSrc,  tCC* pzEnd )
 }
 
 
+LOCAL int
+count_nl(char const * pz)
+{
+    int ct = 0;
+    for (;;) {
+        char const * p = strchr(pz, '\n');
+        if (p == NULL)
+            break;
+        ct++;
+        pz = p + 1;
+    }
+    return ct;
+}
+
+
 LOCAL tCC*
 skipExpression( tCC* pzSrc, size_t len )
 {
