@@ -1,15 +1,14 @@
 
 /*
- *  $Id: tpLoad.c,v 4.26 2008/01/23 00:36:02 bkorb Exp $
+ *  $Id: tpLoad.c,v 4.28 2009/01/01 16:51:44 bkorb Exp $
  *
- * Time-stamp:        "2007-10-30 08:17:58 bkorb"
- * Last Committed:    $Date: 2008/01/23 00:36:02 $
+ * Time-stamp:        "2008-12-25 11:12:48 bkorb"
+ * Last Committed:    $Date: 2009/01/01 16:51:44 $
  *
  *  This module will load a template and return a template structure.
  *
  * This file is part of AutoGen.
- * AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
- * AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
+ * AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -431,6 +430,9 @@ unloadTemplate( tTemplate* pT )
 LOCAL void
 cleanup( tTemplate* pTF )
 {
+    if (HAVE_OPT(USED_DEFINES))
+        print_used_defines();
+
     optionFree(&autogenOptions);
 
     for (;;) {
