@@ -1,38 +1,33 @@
 /*
  *  agTempl.c
- *  $Id: tpProcess.c,v 4.15 2006/12/15 23:24:27 bkorb Exp $
+ *  $Id: tpProcess.c,v 4.23 2009/01/01 16:51:44 bkorb Exp $
  *
  *  Parse and process the template data descriptions
  *
- * Time-stamp:        "2006-12-15 14:14:15 bkorb"
- * Last Committed:    $Date: 2006/12/15 23:24:27 $
+ * Time-stamp:        "2007-11-10 15:55:33 bkorb"
+ * Last Committed:    $Date: 2009/01/01 16:51:44 $
  *
- */
-
-/*
- *  AutoGen copyright 1992-2006 Bruce Korb
+ * This file is part of AutoGen.
+ * AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
  *
- *  AutoGen is free software.
- *  You may redistribute it and/or modify it under the terms of the
- *  GNU General Public License, as published by the Free Software
- *  Foundation; either version 2, or (at your option) any later version.
+ * AutoGen is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *  AutoGen is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * AutoGen is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with AutoGen.  See the file "COPYING".  If not,
- *  write to:  The Free Software Foundation, Inc.,
- *             51 Franklin Street, Fifth Floor,
- *             Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 static tFpStack fpRoot = { 0, NULL, NULL, NULL };
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by :mkfwd */
+/* static forward declarations maintained by mk-fwd */
 static void
 doStdoutTemplate( tTemplate* pTF );
 
@@ -166,6 +161,30 @@ doStdoutTemplate( tTemplate* pTF )
 }
 
 
+LOCAL tOutSpec *
+nextOutSpec(tOutSpec * pOS)
+{
+    tOutSpec * res = pOS->pNext;
+    /*
+     *  The format is either something inside of zFileFormat, we did not
+     *  allocate it.  If it is specifically zSuffix + strlen + 1, then
+     *  is it part of the pOS allocation.  Otherwise, we deallocate it.
+     */
+    if ((pOS->pzFileFmt < zFileFormat) ||
+        (pOS->pzFileFmt >= zFileFormat + sizeof(zFileFormat))) {
+        char const * pz = pOS->zSuffix + strlen(pOS->zSuffix) + 1;
+        if (pOS->pzFileFmt != pz)
+            AGFREE(pOS->pzFileFmt);
+    }
+
+    if (pOS->deallocFmt)
+        AGFREE(pOS->pzFileFmt);
+
+    AGFREE(pOS);
+    return res;
+}
+
+
 LOCAL void
 processTemplate( tTemplate* pTF )
 {
@@ -181,7 +200,7 @@ processTemplate( tTemplate* pTF )
         return;
     }
 
-    for (;;) {
+    do  {
         tOutSpec*  pOS    = pOutSpecList;
 
         /*
@@ -221,8 +240,9 @@ processTemplate( tTemplate* pTF )
              *  We got here by a long jump.  Close/purge the open files.
              */
             do  {
-                closeOutput( AG_TRUE );  /* discard output */
+                closeOutput(AG_TRUE);  /* discard output */
             } while (pCurFp->pPrev != NULL);
+            pzLastScheme = NULL; /* "problem" means "drop current output". */
             break;
 
         default:
@@ -235,26 +255,20 @@ processTemplate( tTemplate* pTF )
              *  We got here by a long jump.  Close/purge the open files.
              */
             do  {
-                closeOutput( AG_TRUE );  /* discard output */
+                closeOutput(AG_TRUE);  /* discard output */
             } while (pCurFp->pPrev != NULL);
 
             /*
              *  On failure (or unknown jump type), we quit the program, too.
              */
             procState = PROC_STATE_ABORTING;
-            exit( EXIT_FAILURE );
+            do pOS = nextOutSpec(pOS);
+            while (pOS != NULL);
+            exit(EXIT_FAILURE);
         }
 
-        /*
-         *  Advance to the next output specification
-         *  and free the old output spec.
-         */
-        pOutSpecList = pOS->pNext;
-        AGFREE( (void*)pOS );
-
-        if (pOutSpecList == NULL)
-            break;
-    }
+        pOutSpecList = nextOutSpec(pOS);
+    } while (pOutSpecList != NULL);
 }
 
 
@@ -326,6 +340,10 @@ openOutFile( tOutSpec* pOutSpec, tFpStack* pStk )
         if (pS++ == NULL)
             pS = pzDefFile;
 
+        /*
+         *  We allow users to specify a suffix with '-' and '_', but when
+         *  stripping a suffix from the "base name", we do not recognize 'em.
+         */
         pE = strchr( pS, '.' );
         if (pE != NULL) {
             size_t len = (unsigned)(pE - pS);
