@@ -1,16 +1,15 @@
 /*
- *  $Id: gdemit.c,v 4.12 2008/01/23 00:36:07 bkorb Exp $
+ *  $Id: gdemit.c,v 4.14 2009/01/18 05:52:31 bkorb Exp $
  *
- *    getdefs copyright 1999-2007 Bruce Korb
+ *    getdefs copyright 1999-2009 by Bruce Korb - all rights reserved
  *
  *  Author:            Bruce Korb <bkorb@gnu.org>
- *  Time-stamp:        "2007-11-04 10:37:09 bkorb"
- *  Last Modified:     $Date: 2008/01/23 00:36:07 $
+ *  Time-stamp:        "2009-01-17 21:28:13 bkorb"
+ *  Last Modified:     $Date: 2009/01/18 05:52:31 $
  *            by: bkorb
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
- *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
  *
  *  AutoGen copyright 1992-2007 Bruce Korb - all rights reserved
  *
@@ -200,11 +199,9 @@ emitDefinition( char* pzDef, char* pzOut )
         while (AG_NAME_CHAR(*pzDef))
             *p++ = *pzOut++ = *pzDef++;
 
-        if (p >= zEntryName + sizeof( zEntryName )) {
-            fprintf( stderr, "getdefs error:  names constrained to %d bytes\n",
-                     MAXNAMELEN );
-            exit( EXIT_FAILURE );
-        }
+        if (p >= zEntryName + sizeof( zEntryName ))
+            die("names are constrained to %d bytes\n", MAXNAMELEN);
+
         *p = NUL;
     }
 
